Einstellungen
=============

Stammdaten
----------

Name
   Der Name des Shops. Dieser wird beispielsweise im Titel-Tag angezeigt.

Shopbetreiber
   Der Shopbetreiber. In der Regel der Firmenname des Shopbetreibers. 
   Dieser wird beispielsweise als Positionsname bei PayPal genutzt.
   
Absender E-Mail Adresse
   Diese E-Mail Adresse wird für ausgehende E-Mails genutzt. Alle gültigen 
   E-Mail-Formate sind erlaubt. Beispiele:

   * shop@iqpp.de
   * Online Shop <shop@iqpp.de>

Empfänger E-Mail Adressen
   An diese E-Mail-Adressen werden eingehende E-Mail Nachrichten gesendet, 
   zum Beispiel Nachrichten über das Kontaktformular oder bei eingehenden 
   Bestellungen.
   
Beschreibung
   Eine Beschreibung des Shops

Bild
   Ein optionales Bild, das je nach Design in verschiedenen Bereichen des Shops 
   angezeigt werden kann, z.B. im Kopf.
   
Statischer Block
   Ein HTML Block, der abhängig vom verwendeten Design in verschiedenen Bereichen
   des Shops angezeigt werden kann, z.B. im Kopf.
   
Standardwerte
-------------

Hier legen Sie diverse Standardwerte fest, die an verschiedenen Stellen in Ihrem
Shop genutzt werden.

Produktspalten
   Vorgabe für die Anzeige der Anzahl von Produktspalten, wenn für eine Kategorie 
   keine Formate aktive sind.
   
Produktzeilen
   Vorgabe für die Anzeige der Anzahl von Produktzeilen, wenn für eine Kategorie 
   keine Formate aktive sind.
   
Kategoriespalten
   Vorgabe für die Anzeige der Anzahl von Kategoriespalten, wenn für eine Kategorie
   keine Formate aktive sind.
   
Auswählbare Länder
   Selektierte Länder werden dem Shopkunden als Lieferland angeboten

Standardland
   Diese Land ist als Lieferland ausgewählt, wenn der Kunde noch keine Auswahl 
   getroffen hat.
